#!/bin/bash

guess_pkgnames() {
    # guess interesting names from folder of RPMs
    ls "$1" \
      | grep rpm\$ \
      | sed -e 's/-[0-9].*$//' \
      | sort \
      | uniq
}

guess_rtag() {
    uname -r | sed -e 's/^[.0-9-]*//; s/\..*$//'
}

guess_rtagn() {
    echo $(guess_rtag) | sed -e 's/[0-9]*$//'
}

installed_versions() {
    # for every prefix print installed versions
    cat - \
        | while read name;
          do rpm -qa "$name*";
          done \
            | sort \
            | uniq
}

nvc_parse() {
    local what="$1"
    local nvc="$2"
    test -n "$2" || warn "usage: nvc_parse WHAT NVC"
    local arch="${nvc##*.}"
    local rest="${nvc%%.$arch}"
    local release="${rest##*-}"
    local rest="${rest%%-$release}"
    local version="${rest##*-}"
    local name="${rest%-*}"
    case $what in
        arch)
            echo $arch
            ;;
        release)
            echo $release
            ;;
        version)
            echo $version
            ;;
        name)
            echo $name
            ;;
        *)
            warn "WHAT = [arch|release|version|name]"
            return 1
    esac
}

save_repo_for() {
    local target=$1
    local rtagn=$(guess_rtagn)
    local uri=$(iniread -s $rtagn -k $target repo_uris.ini)
    think "adding repo for $target"
    debug -v target:rtagn:uri
    case "$uri" in
        INCLUDED)
            ;;
        NONE)
            warn "no repo available for $target"
            return 1
            ;;
        *)
            pushd /etc/yum.repos.d/ >/dev/null
            wget -q "$uri"
            popd >/dev/null
            ;;
    esac
}

yum_preerase() {
    # read package names from stdin and pre-erase them
    cat - \
        | while read pkgname;
          do
              if rpm -q "$pkgname" 2>/dev/null 1>&2;
              then
                  echo "pre-erasing $pkgname"
                  yum -q -y erase "$pkgname"
              fi
          done
}

yum_install() {
    yum -q -y install "$@" 2>&1 | mute_known yum
}

yum_install_if_needed() {
    local pkg
    for pkg in "$@";
    do
        rpm -q $pkg >& /dev/null || yum_install $pkg;
    done
}

yum_update() {
    yum -q -y update "$@" 2>&1 | mute_known yum
}
