#!/bin/bash
# ffood - Fast Food - a Bash Library
# See LICENSE file for copyright and license details.

tmp=$(mktemp)
sed -e 's/ = /=/' < config.mk > $tmp
. $tmp
rm -f $tmp

bindir=${DESTDIR}${PREFIX}/bin
mandir=${DESTDIR}${MANPREFIX}
docdir=${DESTDIR}${PREFIX}/share/doc/ffood
shrdir=${DESTDIR}${PREFIX}/share/ffood

list_of_bins() {
    echo bin/fffun
}

list_of_installed_bins() {
    list_of_bins | sed -e "s/bin/$(sed -e 's/\//\\\//g' <<<$bindir)/"
}

list_of_docs() {
    echo doc/fffun.1.md
    echo doc/ffood.3.md
}

list_of_shrs() {
    echo ffood.sh
    echo include
}

clean() {
    test -f built.list && {
        cat built.list | xargs rm -f
        rm -f built.list
    } || :
}

dist() {
    local dirname=ffood-${VERSION}
    mkdir -p $dirname
    cp -R   bin \
            config.mk \
            doc \
            include \
            Makefile \
            ffood.sh.in \
            README \
            LICENSE \
            setup \
            test \
            $dirname
    tar -cf $dirname.tar $dirname
    gzip $dirname.tar
    rm -rf $dirname
    echo $dirname.tar.gz >> built.list
}

install() {
    mkdir -p $bindir \
             $docdir \
             $shrdir
    list_of_bins | xargs cp -vrt $bindir
    list_of_docs | xargs cp -vrt $docdir
    list_of_shrs | xargs cp -vrt $shrdir
    list_of_installed_bins | xargs chmod 755
    test -f .autoclean && clean || :
}

manpages() {
    ronn -r doc/*.[1-9].md
    ls doc/*.[1-9] >> built.list
}

install_manpages() {
    cp -vr doc/*.1 $mandir/man1
    cp -vr doc/*.3 $mandir/man3
    test -f .autoclean && clean || :
}

ffood() {
    local srcpath dstpath
    find -type f -name '*.in' \
        | while read srcpath;
          do
              dstpath=${srcpath%.in}
              perl -pe "s|__FFOOD_DIR__|$shrdir|;
                        s|__VERSION__|$VERSION|;" < $srcpath > $dstpath
              echo $dstpath >> built.list
          done
}

run_test() {
    pushd test
    find -maxdepth 1 -type f \! -name '*.in' | while read test;
    do
        chmod 0755 $test
        $test || exit $?
    done
    popd
}

uninstall() {
    list_of_installed_bins | xargs rm -f
    rm -rf $shrdir/ffood
    rm -rf $docdir/ffood
    rm -f $mandir/man1/fffun.1
    rm -f $mandir/man3/ffood.3
}

case $1 in
    clean|dist|install|install_manpages|manpages|ffood|uninstall)
        $1
        ;;
    test)
        run_test
        ;;
    *)
        echo "usage: $(basename $0) clean|dist|install|ffood|test|uninstall" >&2
esac
